@@ -8,6 +8,7 @@ from ..const import (
     TEST_ACCOUNT_ID,
     TEST_LOCK_ID,
     TEST_LOCK_ID_2,
+    TEST_LOCK_ID_3,
     TEST_SUBSCRIPTION_ID,
     TEST_SYSTEM_ID,
     TEST_SYSTEM_SERIAL_NO,
@@ -511,6 +512,50 @@ def v3_sensors_json():
                     "offline": False,
                 },
             },
+            {
+                "serial": TEST_LOCK_ID_3,
+                "type": 16,
+                "status": {
+                    "pinPadState": 0,
+                    "lockState": 42,
+                    "pinPadOffline": False,
+                    "pinPadLowBattery": False,
+                    "lockDisabled": False,
+                    "lockLowBattery": False,
+                    "calibrationErrDelta": 0,
+                    "calibrationErrZero": 0,
+                    "lockJamState": 0,
+                },
+                "name": "Side Door",
+                "deviceGroupID": 1,
+                "firmwareVersion": "1.0.0",
+                "bootVersion": "1.0.0",
+                "setting": {
+                    "autoLock": 3,
+                    "away": 1,
+                    "home": 1,
+                    "awayToOff": 0,
+                    "homeToOff": 1,
+                },
+                "flags": {
+                    "swingerShutdown": False,
+                    "lowBattery": False,
+                    "offline": False,
+                },
+            },
+            {
+                "serial": "654",
+                "type": 253,
+                "status": {},
+                "name": "Front Door",
+                "deviceGroupID": 1,
+                "setting": {},
+                "flags": {
+                    "swingerShutdown": False,
+                    "lowBattery": False,
+                    "offline": False,
+                },
+            },
         ],
         "lastUpdated": 1534626361,
         "lastSynced": 1534626361,
